@@ -36,6 +36,10 @@ func main() {
 				if _, err := io.Copy(sb, os.Stdin); err == nil {
 					if stdin := strings.TrimSpace(sb.String()); stdin != crontab {
 						err = fmt.Errorf("%q != %q", crontab, stdin)
+						if err != nil {
+							fmt.Fprintln(os.Stderr, err)
+							// os.Exit(1)
+						}
 					}
 				}
 			} else {
