@@ -9,6 +9,7 @@ import (
 	"fmt"
 	"io"
 	"net/http"
+	urlpkg "net/url"
 	"os"
 	"path/filepath"
 	"regexp"
@@ -19,6 +20,7 @@ import (
 	"github.com/creativeprojects/clog"
 	"github.com/creativeprojects/resticprofile/config"
 	"github.com/creativeprojects/resticprofile/constants"
+	"github.com/creativeprojects/resticprofile/util"
 	"github.com/creativeprojects/resticprofile/util/templates"
 )
 
@@ -70,12 +72,17 @@ func NewSender(certificates []string, userAgent string, timeout time.Duration, d
 	}
 }
 
-func (s *Sender) Send(cfg config.SendMonitoringSection, ctx Context) error {
+func (s *Sender) Send(cfg config.SendMonitoringSection, ctx Context, env *util.Environment) error {
 	if cfg.URL.Value() == "" {
 		return errors.New("URL field is empty")
 	}
-	url := resolve(cfg.URL.Value(), ctx)
-	publicUrl := resolve(cfg.URL.String(), ctx)
+
+	if env == nil {
+		env = util.NewDefaultEnvironment(os.Environ()...)
+	}
+
+	url := resolveURL(cfg.URL.Value(), ctx, env)
+	publicUrl := resolveURL(cfg.URL.String(), ctx, env)
 	method := cfg.Method
 	if method == "" {
 		method = http.MethodGet
@@ -93,7 +100,7 @@ func (s *Sender) Send(cfg config.SendMonitoringSection, ctx Context) error {
 		bodyReader = bytes.NewBufferString(body)
 	}
 	if cfg.Body != "" {
-		body = resolve(cfg.Body, ctx)
+		body = resolveBody(cfg.Body, ctx, env)
 		bodyReader = bytes.NewBufferString(body)
 	}
 
@@ -202,8 +209,8 @@ func getRootCAs(certificates []string) *x509.CertPool {
 	return caCertPool
 }
 
-func resolve(body string, ctx Context) string {
-	body = os.Expand(body, func(s string) string {
+func resolveBody(body string, ctx Context, env *util.Environment) string {
+	return os.Expand(body, func(s string) string {
 		switch s {
 		case constants.EnvProfileName:
 			return ctx.ProfileName
@@ -227,10 +234,39 @@ func resolve(body string, ctx Context) string {
 			return "$" // allow to escape "$" as "$$"
 
 		default:
-			return os.Getenv(s)
+			return env.Get(s)
+		}
+	})
+}
+
+func resolveURL(url string, ctx Context, env *util.Environment) string {
+	return os.Expand(url, func(s string) string {
+		switch s {
+		case constants.EnvProfileName:
+			return ctx.ProfileName
+
+		case constants.EnvProfileCommand:
+			return ctx.ProfileCommand
+
+		case constants.EnvError:
+			return urlpkg.QueryEscape(ctx.Error.Message)
+
+		case constants.EnvErrorCommandLine:
+			return urlpkg.QueryEscape(ctx.Error.CommandLine)
+
+		case constants.EnvErrorExitCode:
+			return ctx.Error.ExitCode
+
+		case constants.EnvErrorStderr:
+			return urlpkg.QueryEscape(ctx.Error.Stderr)
+
+		case "$":
+			return "$" // allow to escape "$" as "$$"
+
+		default:
+			return env.Get(s)
 		}
 	})
-	return body
 }
 
 func loadBodyTemplate(filename string, ctx Context) (string, error) {
