@@ -51,13 +51,28 @@ func Create(config *Config, schedules []*calendar.Event, permission Permission)
 			return fmt.Errorf("cannot delete existing task to replace it: %w", err)
 		}
 	}
+
 	task := createTaskDefinition(config, schedules)
 	task.RegistrationInfo.URI = taskPath
 
+	switch config.RunLevel {
+	case "lowest":
+		task.Principals.Principal.RunLevel = RunLevelLeastPrivilege
+
+	case "highest":
+		task.Principals.Principal.RunLevel = RunLevelHighest
+
+	default:
+		if permission == SystemAccount {
+			task.Principals.Principal.RunLevel = RunLevelHighest
+		} else {
+			task.Principals.Principal.RunLevel = RunLevelDefault
+		}
+	}
+
 	switch permission {
 	case SystemAccount:
 		task.Principals.Principal.LogonType = LogonTypeServiceForUser
-		task.Principals.Principal.RunLevel = RunLevelHighest
 		task.Principals.Principal.UserId = serviceAccount
 		task.RegistrationInfo.SecurityDescriptor = securityDescriptor // allow authenticated users to read the task status
 
@@ -131,12 +146,10 @@ func Registered() ([]Config, error) {
 
 	configs := make([]Config, 0, len(list))
 	for _, taskPath := range list {
+		clog.Debugf("loading task %q", taskPath)
 		info, err := getTaskInfo(taskPath)
 		if err != nil {
-			clog.Errorf("loading task %q: %w", taskPath, err)
-			continue
-		}
-		if len(info) < 2 {
+			clog.Errorf("loading task %q: %s", taskPath, err)
 			continue
 		}
 		taskName := strings.TrimPrefix(taskPath, tasksPathPrefix)
@@ -177,11 +190,3 @@ func createTaskDefinition(config *Config, schedules []*calendar.Event) Task {
 	task.AddSchedules(schedules)
 	return task
 }
-
-func getFirstField(data [][]string, fieldName string) string {
-	index := slices.Index(data[0], fieldName)
-	if index < 0 {
-		return ""
-	}
-	return data[1][index]
-}
