@@ -4,8 +4,10 @@ package systemd
 
 import (
 	"bufio"
+	"errors"
 	"fmt"
 	"io"
+	"io/fs"
 	"path/filepath"
 	"regexp"
 	"strings"
@@ -23,6 +25,18 @@ func getOwnedName(basename string) string {
 	return fmt.Sprintf("%s.resticprofile.conf", strings.TrimSuffix(basename, ext))
 }
 
+func (u Unit) DropInFileExists(file string) bool {
+	if _, err := u.fs.Stat(file); err != nil {
+		if errors.Is(err, fs.ErrNotExist) {
+			clog.Errorf("drop-in file %q not found", file)
+			return false
+		}
+		clog.Error(err)
+		return false
+	}
+	return true
+}
+
 func (u Unit) IsTimerDropIn(file string) bool {
 	if f, err := u.fs.Open(file); err == nil {
 		defer func() { _ = f.Close() }()
